import { Component } from '@angular/core';
import { TableModel } from 'src/app/shared/interfaces/table-model.interface';
import { ReservationDetail } from '../../interfaces/reservation-detail.interface';
import { TableAction } from 'src/app/shared/interfaces/table-action.interface';
import { Router } from '@angular/router';
import { FormControl, FormGroup, Validators } from '@angular/forms';

@Component({
  selector: 'passenger-my-reservations',
  templateUrl: './my-reservations.component.html',
  styleUrls: ['./my-reservations.component.css']
})
export class MyReservationsComponent {

  public actions: TableAction[] = [
    {
      title: 'Editar',
      icon: 'bi-pencil-square',
      action: (item) => { console.log(item); }
    },
    {
      title: 'Eliminar',
      icon: 'bi-trash',
      action: (item) => { console.log(item); }
    },
    {
      title: "Pagar",
      icon: "bi-cash",
      action: () => { this.onTogleDialogPay(); }
    }
  ];

  public tableModel: TableModel[] = [
    {
      name: 'id',
      title: '#',
    },
    {
      name: 'origin',
      title: 'Origen',
    },
    {
      name: 'destination',
      title: 'Destino',
    },
    {
      name: 'date',
      title: 'Fecha',
    },
    {
      name: 'status',
      title: 'Estado',
    },
    {
      name: 'cost',
      title: 'Costo',
    }
  ]
  public tableData: ReservationDetail[] = [
    {
      id: 1,
      origin: 'Bogotá',
      destination: 'Medellín',
      date: '2021-10-10',
      status: 'Activo',
      cost: 1500
    },
    {
      id: 2,
      origin: 'Bogotá',
      destination: 'Medellín',
      date: '2021-10-10',
      status: 'Activo',
      cost: 1500
    }
  ];

  cardControl = new FormControl<string>('', [Validators.required]);
  expirationControl = new FormControl<string>('', [Validators.required]);
  cvvControl = new FormControl<string>('', [Validators.required]);
  ownerControl = new FormControl<string>('', [Validators.required]);

  formGroup = new FormGroup({
    card: this.cardControl,
    expiration: this.expirationControl,
    cvv: this.cvvControl,
    owner: this.ownerControl,
  });

  onSave(): void {
    console.log(this.formGroup.value);

  }

  // formPay = new FormGroup<string>({
  //   name: new FormControl<string>('', [Validators.required]),
  // });

  public openDialogPay: boolean = false;

  constructor(private router: Router) {}

  onClickItem(item: ReservationDetail): void {
    this.router.navigate(['/passenger/reservations', item.id]);
  }

  onTogleDialogPay(): void {
    this.openDialogPay = !this.openDialogPay;
  }
}
